@@ -71,10 +71,10 @@ module OpenID
       # verified information.
       def id_res
         check_for_fields
-        verify_return_to
-        verify_discovery_results
         check_signature
         check_nonce
+        verify_return_to
+        verify_discovery_results
       end
 
       def server_url
@@ -160,7 +160,7 @@ module OpenID
         query = @message.to_post_args
         return_to_parsed_query.each_pair do |rt_key, rt_val|
           msg_val = query[rt_key]
-          if msg_val.nil?
+          if msg_val.nil? && !rt_val.nil?
             raise ProtocolError, "Message missing return_to argument '#{rt_key}'"
           elsif msg_val != rt_val
             raise ProtocolError, ("Parameter '#{rt_key}' value "\
@@ -296,7 +296,7 @@ module OpenID
 
         begin
           time, extra = Nonce.split_nonce(nonce)
-        rescue ArgumentError => why
+        rescue ArgumentError
           raise ProtocolError, "Malformed nonce: #{nonce.inspect}"
         end
 
